@@ -1,6 +1,8 @@
 package Vimana::Command::Remove;
-use parent qw(App::CLI::Command);
+use base qw(App::CLI::Command);
+use Vimana::Logger;
 use Vimana::Record;
+use Vimana::PackageFile;
 
 sub options { 
     ( 
@@ -12,26 +14,6 @@ sub options {
 sub run {
     my ( $self, $package ) = @_;
     Vimana::Record->remove( $package , $self->{force} );
-
-
 }
 
 1;
-__END__
-
-
-=head1 NAME
-
-Vimana::Command::Remove - {Description}
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-=head1 FUNCTION
-
-=head1 AUTHOR
-
-
-
-
