@@ -4,12 +4,12 @@ use strict;
 use URI;
 require LWP::UserAgent;
 require Vimana::VimOnline;
-use parent qw(App::CLI::Command);
+use base qw(App::CLI::Command);
 
 sub options {
     (
-        'v|verbose'       => 'verbose',
-        't|type=s'        => 'script_type',
+        'v|verbose'     => 'verbose',
+        't|script-type=s' => 'script_type',
         'o|order-by=s',   => 'order_by',
     );
 }
@@ -18,14 +18,19 @@ sub options {
 sub run {
     my ( $self, @keywords ) = @_;
 
+    unless( @keywords ) {
+        warn "Please specify keyword";
+        exit 0; 
+    }
+
     my $index = Vimana->index();
     my $plugins = $index->read_index();
 
     unless( $plugins ) {
-        print "Updating index..\n";
+        print "Can not found index. Fetching..\n";
         my $result = Vimana::VimOnline::Search->fetch(
                 keyword => '',
-                show_me => Vimana::VimOnline::Search->all_vim_plugins,
+                show_me => 3000,
                 order_by => 'creation_date',
                 direction => 'ascending'
         );
@@ -35,26 +40,20 @@ sub run {
     }
 
 
-    my $keyword;
-    $keyword = pop @keywords if @keywords;
-
-    my @result = values %$plugins;
-    @result = map { ( $_->{description} =~ /$keyword/ or $_->{plugin_name} =~ /$keyword/ ) ? $_ : ()  } @result if $keyword;
-
-    @result = map { $_->{type} =~ /@{[ $self->{script_type} ]}/i ? $_ : ()  } @result if $self->{script_type};
+    my $keyword = $keywords[0]; # FIXME:
+    my @result = map { ( $_->{description} =~ /$keyword/ or $_->{plugin_name} =~ /$keyword/ ) ? $_ : ()  } values %$plugins;
 
     my $max_width = 6;
-    map { $max_width = length($_->{plugin_name}) if length($_->{plugin_name}) > $max_width }  @result;
+    map { $max_width = length $_->{plugin_name} if length $_->{plugin_name} > $max_width }  @result;
     $max_width += 1;
 
     for ( @result ) {
         print $_->{plugin_name};
-        print ' ' x ( $max_width - length($_->{plugin_name}));
-        print ' [' . $_->{type} . ']';
-        print ' ' x (12 - length($_->{type}));
-        print " @{[ $_->{description} ]}\n";
+        print ' ' x ( $max_width - length $_->{plugin_name} );
+        print " - " . $_->{description} . "\n";
     }
 
+
     # XXX: Search from Index
 #    my $results = Vimana::VimOnline::Search->fetch(
 #        keywords     => join(' ' , @keywords) ,
@@ -69,20 +68,3 @@ sub run {
 
 
 1;
-__END__
-
-=head1 NAME
-
-Vimana::Command::Search - search vim plugins.
-
-=head1 SYNOPSIS
-
-    $ vimana search [options] [keyword]
-
-=head1 OPTIONS
-
--t,--type [type]
-
-    script type
-
-=cut
