@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 # use re 'debug';
-use File::Copy::Recursive qw(fcopy rcopy dircopy fmove rmove dirmove);
+use Vimana::Recursive qw(dircopy_files);
 use File::Spec;
 use File::Path qw'mkpath rmtree';
 use Archive::Any;
@@ -14,34 +14,17 @@ use Vimana::Logger;
 use Vimana::Util;
 use DateTime;
 
-sub find_vimball_files {
-    my $out = shift;
-    my @vimballs;
-    File::Find::find(  sub {
-            return unless -f $_;
-            push @vimballs , File::Spec->join($File::Find::dir , $_ ) if /\.vba$/;
-        } , $out );
-    return @vimballs;
-}
-
-
-sub find_files {
-    my $self = shift;
-    my @dirs = @_;
-    use File::Find;
-    use File::Spec;
-    my @files;
-    File::Find::find(sub {
-        return if m{\.(?:git|svn)};
-        return if $File::Find::dir =~ m{\.(git|svn)};
-        my $filepath = File::Spec->catfile( $File::Find::dir, $_ );
-        push @files, $filepath if -f $_;
-    } , @dirs );
-    return @files;
-}
-
 sub run {
-    my ($self, $out ) = @_;
+    my ( $self, $pkgfile, $out ) = @_;
+
+    # XXX: try to fill the record spec.
+    my $record = {
+        install_type => 'auto',
+        meta => {} ,
+        files => [ ],
+    };
+
+
     my @files = $self->find_files( '.' );
 
     print "Archive content:\n";
@@ -49,11 +32,12 @@ sub run {
         print "\t$_\n";
     }
 
-    if( grep /\.vba$/,@files ) {
-        $logger->info( "vimball files found, trying to install vimball files");
+    my @vba = grep /\.vba/,@files;
+    if( @vba ) {
+        $logger->info( "Found vimball files, try to install vimball files");
         use Vimana::VimballInstall;
-        my @vimballs = find_vimball_files $out;
-        Vimana::VimballInstall->install_vimballs( @vimballs );
+        # my @vimballs = find_vimball_files $out;
+        Vimana::VimballInstall->install_vimballs( @vba );
     }
 
     # check directory structure
@@ -73,17 +57,41 @@ sub run {
 
         # XXX: check vim runtime path subdirs , mv to init script
         $logger->info("Initializing vim runtime directories") ;
-        Vimana::Util::init_vim_runtime();
+        Vimana::Util::init_vim_runtime( $self->runtime_path );
         
         $logger->info( "Basepath found: " . $_ ) for ( keys %$nodes );
 
-        $self->install_from_nodes( $nodes , runtime_path() );
+        my @installed_files = $self->install_from_nodes( $nodes , $self->runtime_path );
 
         $logger->info("Updating helptags");
         $self->update_vim_doc_tags();
+
+        # record installed file checksum
+        print "Making checksum...\n";
+        my @e = Vimana::Record->mk_file_digests( @installed_files );
+
+        Vimana::Record->add( {
+                version => 0.2,    # record spec version
+                generated_by => 'Vimana-' . $Vimana::VERSION,
+                install_type => 'auto',    # auto , make , rake ... etc
+                package => $pkgfile->cname,
+                files => \@e,
+
+                #            meta => {
+                #                author =>  'Cornelius',
+                #                email =>  'cornelius.howl@gmail.com',
+                #                libpath => '',
+                #                name => 'gsession.vim',
+                #                script_id => 2885,
+                #                type => 'plugin'
+                #                version =>  '0.21',
+                #                version_from => 'plugin/gsession.vim'
+                #                vim_version => '',
+                #            },
+        } );
     }
 
-    if( $self->args and $self->args->{cleanup} ) {
+    if( $self->cleanup ) {
         $logger->info("Cleaning up temporary directory.");
         rmtree [ $out ] if -e $out;
     }
@@ -98,10 +106,12 @@ sub run {
 sub install_from_nodes {
     my ($self , $nodes , $to ) = @_;
     $logger->info("Copying files...");
-    for my $node  ( grep { $nodes->{ $_ } > 1 } keys %$nodes ) {
-        $logger->info("$node => $to");
-        my (@ret) = dircopy($node, $to );
+    my @copied = ();
+    for my $basedir  ( grep { $nodes->{ $_ } > 1 } keys %$nodes ) {
+        $logger->info("$basedir => $to");
+        push @copied , dircopy_files($basedir, $to );
     }
+    return @copied;
 }
 
 =head2 find_base_path 
@@ -121,13 +131,41 @@ sub find_base_path {
 }
 
 sub update_vim_doc_tags {
+    my $self = shift;
     my $vim = find_vim();
-    my $dir = File::Spec->join( runtime_path() , 'doc' );
+    my $dir = File::Spec->join( $self->runtime_path , 'doc' );
     my $cmd = qq{vim -e -s -c ":helptags $dir" -c ":q"};
     print "\t$cmd\n";
     system( $cmd );
 }
 
+sub find_vimball_files {
+    my $out = shift;
+    my @vimballs;
+    File::Find::find(  sub {
+            return unless -f $_;
+            push @vimballs , File::Spec->join($File::Find::dir , $_ ) if /\.vba$/;
+        } , $out );
+    return @vimballs;
+}
+
+sub find_files {
+    my $self = shift;
+    my @dirs = @_;
+    use File::Find;
+    use File::Spec;
+    my @files;
+    File::Find::find(sub {
+        return if m{\.(?:git|svn)};
+        return if $File::Find::dir =~ m{\.(git|svn)};
+        my $filepath = File::Spec->catfile( $File::Find::dir, $_ );
+        push @files, $filepath if -f $_;
+    } , @dirs );
+    return @files;
+}
+
+
+
 
 =head1 AUTHOR
 
