@@ -6,8 +6,7 @@ use Vimana::Logger;
 use Vimana::VimballInstall;
 
 sub run {
-    my $self = shift;
-    my $pkgfile = $self->package;
+    my ( $self, $pkgfile ) = @_;
 
     if( $pkgfile->is_vimball ) {
         $logger->info("Found Vimball File");
@@ -17,16 +16,16 @@ sub run {
     }
 
     # known types (depends on the information that vim.org provides.
-    return $pkgfile->copy_to_rtp( 'colors' )
+    return $pkgfile->copy_to_rtp( File::Spec->join( $self->runtime_path ,  'colors' ) )
         if $pkgfile->script_is('color scheme');
 
-    return $pkgfile->copy_to_rtp( 'syntax' )
+    return $pkgfile->copy_to_rtp( File::Spec->join( $self->runtime_path ,  'syntax' ) )
         if $pkgfile->script_is('syntax');
 
-    return $pkgfile->copy_to_rtp( 'indent' )
+    return $pkgfile->copy_to_rtp( File::Spec->join( $self->runtime_path , 'indent' ) )
         if $pkgfile->script_is('indent');
 
-    return $pkgfile->copy_to_rtp( 'ftplugin' )
+    return $pkgfile->copy_to_rtp( File::Spec->join( $self->runtime_path , 'ftplugin' ) )
         if $pkgfile->script_is('ftplugin');
 
     # guess text filetype here.  (colorscheme, ftplugin ...etc)
@@ -36,7 +35,7 @@ sub run {
     if ($type) {
         $logger->info("Script type found: $type.");
         $logger->info("Installing..");
-        $self->copy_to_rtp($type);
+        $self->copy_to_rtp( File::Spec->join( $self->runtime_path, $type ) );
         $logger->info("Done.");
         return 1;
     }
@@ -44,6 +43,16 @@ sub run {
 }
 
 
+=head2 inspect_text_content
+
+you can add something like this to your vim script file:
+
+    " script type: plugin
+
+then the file will be installed into ~/.vim/plugin/
+
+=cut
+
 sub inspect_text_content {
     my $self = shift;
     my $content = $self->package->content;
@@ -51,6 +60,12 @@ sub inspect_text_content {
     return 'syntax'   if $content =~ m/^syn[tax]* (?:match|region|keyword)/;
     return 'compiler' if $content =~ m/^let\s+current_compiler\s*=/;
     return 'indent'   if $content =~ m/^let\s+b:did_indent/;
+
+    if( $content =~ m{^"\s*(?:script\s+type):\s*(\w+)}i ) {
+        my $type = $1;
+        return $type;
+        # return $type if $type =~ m{(?:plugin|ftplugin|ftdetect|syntax|compiler|)};
+    }
     return 0;
 }
 
