@@ -40,7 +40,8 @@ __PACKAGE__->mk_accessors( qw(
 
 =cut
 
-sub is_archive { $_[ 0 ]->filetype =~ m{(x-bzip2|x-gzip|x-gtar|zip|rar|tar)} ? 1 : 0; }
+# only add supported archive types
+sub is_archive { $_[ 0 ]->filetype =~ m{(?:x-bzip2|x-gzip|x-gtar|zip|rar|tar)} ? 1 : 0; }
 
 sub is_text { $_[ 0 ]->filetype =~ m{octet-stream} ? 1 : 0 }
 
@@ -61,7 +62,8 @@ sub download {
 
     unlink $self->file if -e $self->file;
 
-    open FH, ">", $self->file or die $@;
+    print "Saving file to @{[ $self->file ]} \n";
+    open FH, ">", $self->file or die $!;
     print FH $file_content;
     close FH;
 
@@ -157,15 +159,14 @@ sub copy_to {
 }
 
 
-=head2 $pkgfile->copy_to_rtp( $type )
+=head2 $pkgfile->copy_to_rtp( $dir )
 
 copy to vim runtime path
 
 =cut
 
 sub copy_to_rtp {
-    my ( $self, $type ) = @_ ;
-    my $target = File::Spec->join( runtime_path(), $type );
+    my ( $self, $target ) = @_ ;
     return $self->copy_to($target);
 }
 
